@@ -4,9 +4,11 @@ from .client import RosClient
 from .exceptions import RosError
 from .exceptions import RosValidationError
 from .fileserver_loader import RosFileServerLoader
+from .messages import ROSmsg
 from .planner import MoveItPlanner
 
 __all__ = [
+    'ROSmsg',
     'RosClient',
     'RosFileServerLoader',
     'RosError',
